.. Fiona documentation master file, created by
   sphinx-quickstart on Mon Dec 26 12:16:26 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Fiona's documentation!
=================================

Contents:

.. toctree::
   :maxdepth: 2

   README.rst
   manual.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

